@@ -5,6 +5,8 @@ from Orange.data.io import detect_encoding
 from gensim import corpora
 from nltk.corpus import stopwords
 
+from orangecontrib.text.misc import wait_nltk_data
+
 __all__ = ['BaseTokenFilter', 'StopwordsFilter', 'LexiconFilter', 'RegexpFilter', 'FrequencyFilter']
 
 
@@ -43,28 +45,42 @@ class WordListMixin:
 
     def from_file(self, path):
         self.file_path = path
+        self.word_list = []
         if not path:
-            self.word_list = []
-        else:
-            enc = detect_encoding(path)
-            with open(path, encoding=enc) as f:
-                self.word_list = set([line.strip() for line in f])
+            return
 
-# get NLTK list of stopwords
-stopwords_listdir = []
-try:
-    stopwords_listdir = [file for file in os.listdir(stopwords._get_root())
-                         if file.islower()]
-except LookupError:     # when no NLTK data is available
-    pass
+        for encoding in ('utf-8',
+                         None,  # sys.getdefaultencoding()
+                         detect_encoding(path)):
+            try:
+                with open(path, encoding=encoding) as f:
+                    self.word_list = set(line.strip() for line in f)
+            except UnicodeDecodeError:
+                continue
+            return
+        # No encoding worked, raise
+        raise UnicodeError("Couldn't determine file encoding")
 
 
 class StopwordsFilter(BaseTokenFilter, WordListMixin):
     """ Remove tokens present in NLTK's language specific lists or a file. """
     name = 'Stopwords'
 
-    supported_languages = [file.capitalize() for file in stopwords_listdir]
+    @staticmethod
+    @wait_nltk_data
+    def supported_languages():
+        # get NLTK list of stopwords
+        stopwords_listdir = []
+        try:
+            stopwords_listdir = [file for file in
+                                 os.listdir(stopwords._get_root())
+                                 if file.islower()]
+        except LookupError:  # when no NLTK data is available
+            pass
 
+        return [file.capitalize() for file in stopwords_listdir]
+
+    @wait_nltk_data
     def __init__(self, language='English', word_list=None):
         WordListMixin.__init__(self, word_list)
         super().__init__()
