@@ -1,7 +1,7 @@
 # Category metadata.
 
 # Category icon show in the menu
-ICON = "icons/WordNGrams.svg"
+ICON = "icons/category.svg"
 
 # Background color for category background in menu
 # and widget icon background in workflow.
