@@ -312,7 +312,7 @@ class FilteringModule(MultipleMethodModule):
     REGEXP = 2
     FREQUENCY = 3
     KEEP_N = 4
-    dlgFormats = 'Only text files (*.txt)'
+    dlgFormats = 'Only text files (*.txt);;All files (*)'
 
     stopwords_language = settings.Setting('English')
 
@@ -320,7 +320,7 @@ class FilteringModule(MultipleMethodModule):
     recent_lexicon_files = settings.Setting([])
 
     pattern = settings.Setting('\.|,|:|;|!|\?|\(|\)|\||\+|\'|\"|‘|’|“|”|\'|\’'
-                               '|…|\-|–|—|\$|&|\*|>|<')
+                               '|…|\-|–|—|\$|&|\*|>|<|\/|\[|\]')
     min_df = settings.Setting(0.1)
     max_df = settings.Setting(0.9)
     keep_n = settings.Setting(100)
@@ -331,7 +331,7 @@ class FilteringModule(MultipleMethodModule):
         super().__init__(master)
 
         box = widgets.ComboBox(self, 'stopwords_language',
-                               items=[None] + preprocess.StopwordsFilter.supported_languages)
+                               items=[None] + preprocess.StopwordsFilter.supported_languages())
         box.currentIndexChanged.connect(self.stopwords_changed)
         self.stopwords_changed()
         self.method_layout.addWidget(box, self.STOPWORDS, 1)
