@@ -19,7 +19,7 @@ from orangecontrib.text.topics import Topic
 
 class OWWordCloud(widget.OWWidget):
     name = "Word Cloud"
-    priority = 10000
+    priority = 510
     icon = "icons/WordCloud.svg"
 
     class Inputs:
@@ -36,7 +36,7 @@ class OWWordCloud(widget.OWWidget):
     selected_words = settings.Setting(set(), schema_only=True)
 
     words_color = settings.Setting(True)
-    words_tilt = settings.Setting(2)
+    words_tilt = settings.Setting(0)
 
     class Warning(widget.OWWidget.Warning):
         topic_precedence = widget.Msg('Input signal Topic takes priority over Corpus')
@@ -296,6 +296,9 @@ span.selected {color:red !important}
             topic.name = 'Selected Words'
         self.Outputs.selected_words.send(topic)
 
+    def send_report(self):
+        self.report_table(self.tableview)
+
 
 def main():
     from Orange.data import Table, Domain, ContinuousVariable, StringVariable
